@@ -18,6 +18,8 @@ DEFAULTS = {
     'AUTO_GENERATE_TASKS_DEFAULT_CELERY_KWARGS': None,
     'AUTO_SQS_MESSAGE_GROUP_ID': False,
     'CELERY_TASK_CHECKER': None,
+    'CELERY_SETTINGS': None,
+    'CELERY_AUTODISCOVER': False,
 }
 
 
